This is an example text, that I'll try to reformat. It should be relatively long to make sure I can deal with long lines.

Here is a second line, or paragraph, not sure
With some second lines. 

   Here is some indented stuff

And back to a third
